import{d as p,z as m,b as r,c as t,g as l,e as d,u as s,a0 as u}from"./index-103db515.js";import{w as v}from"./VListItem-ab7a82e2.js";const f=["title","innerHTML"],c=["title","innerHTML"],M=p({__name:"ProviderIcon",props:{domain:{},size:{},dark:{type:Boolean}},setup(a){const n=a,i=m(()=>{if(n.domain in r.providers)return r.providers[n.domain].domain;if(n.domain in r.providerManifests)return n.domain});return(e,o)=>(t(),l("div",{style:u(`width:${e.size}px;margin-left:10px;margin-right:10px`)},[e.domain&&e.domain=="library"?(t(),d(v,{key:0,size:e.size,icon:"mdi-bookshelf",title:e.$t("item_in_library")},null,8,["size","title"])):e.$vuetify.theme.current.dark&&i.value&&s(r).providerManifests[i.value].icon_svg_dark?(t(),l("div",{key:1,style:u(`width: ${e.size}px`),title:s(r).providerManifests[i.value].name,innerHTML:s(r).providerManifests[i.value].icon_svg_dark},null,12,f)):i.value&&s(r).providerManifests[i.value].icon_svg?(t(),l("div",{key:2,style:u(`width: ${e.size}px;height: ${e.size}px`),title:s(r).providerManifests[i.value].name,innerHTML:s(r).providerManifests[i.value].icon_svg},null,12,c)):i.value&&s(r).providerManifests[i.value].icon?(t(),d(v,{key:3,size:e.size,icon:"mdi-"+s(r).providerManifests[i.value].icon,title:s(r).providerManifests[i.value].name,dark:e.$vuetify.theme.current.dark},null,8,["size","icon","title","dark"])):(t(),d(v,{key:4,size:e.size,dark:e.$vuetify.theme.current.dark,icon:"mdi-playlist-play"},null,8,["size","dark"]))],4))}});function k(a){return{all:a=a||new Map,on:function(n,i){var e=a.get(n);e?e.push(i):a.set(n,[i])},off:function(n,i){var e=a.get(n);e&&(i?e.splice(e.indexOf(i)>>>0,1):a.set(n,[]))},emit:function(n,i){var e=a.get(n);e&&e.slice().map(function(o){o(i)}),(e=a.get("*"))&&e.slice().map(function(o){o(n,i)})}}}const h=k();export{M as _,h as e};
