import{z as r,a8 as c,l as i,m as u,J as d,f as p,c as f,e as v,Z as _,h as m,G as C,w as y,a1 as P}from"./index-103db515.js";import{_ as g}from"./_plugin-vue_export-helper-c27b6911.js";/* empty css              */import{m as k,b as V,c as b}from"./VListItem-ab7a82e2.js";const h={props:{variant:{type:String,default:"default",validator:e=>["default","panel"].includes(e)}},setup(e,n){const a=r(()=>({class:"container-default"})),t=r(()=>({class:c.theme.current.value.dark?"container-default container-panels-dark":"container-default container-panels-light"}));return{btnProps:r(()=>{switch(e.variant){case"default":return a.value;case"panel":return t.value;default:return a.value}})}}};const w=i({fluid:{type:Boolean,default:!1},...k(),...V()},"VContainer"),$=u()({name:"VContainer",props:w(),setup(e,n){let{slots:a}=n;const{rtlClasses:t}=d();return b(()=>p(e.tag,{class:["v-container",{"v-container--fluid":e.fluid},t.value,e.class],style:e.style},a)),{}}});function x(e,n,a,t,o,l){return f(),v($,C(t.btnProps,{variant:"default",fluid:""}),_({_:2},[m(e.$slots,(B,s)=>({name:s,fn:y(()=>[P(e.$slots,s,{},void 0,!0)])}))]),1040)}const F=g(h,[["render",x],["__scopeId","data-v-7629334b"]]);export{F as C};
