import{B as v}from"./Button-412f73ce.js";import{z as i,n as c,R as B,Q as _,c as a,e as m,Z as I,h as $,w as p,a1 as l,a4 as u,j as w,G as M}from"./index-103db515.js";import{_ as h}from"./_plugin-vue_export-helper-c27b6911.js";import{V as k}from"./VListItem-ab7a82e2.js";const y={components:{MAButton:v},props:{showMenuBtn:{type:Boolean,default:!1}},setup(t,e){const o=i(()=>({}));return{listItemProps:i(()=>({...o.value,...e.attrs}))}}};function C(t,e,o,n,L,P){const d=c("MAButton"),f=B("hold");return _((a(),m(k,M(n.listItemProps,{class:"list-item-main",onInput:e[1]||(e[1]=s=>t.$emit("input",s)),onContextmenu:e[2]||(e[2]=u(s=>t.$emit("menu",s),["right","prevent"]))}),I({_:2},[$(t.$slots,(s,r)=>({name:r,fn:p(()=>[l(t.$slots,r,{},void 0,!0)])})),t.$slots.append||o.showMenuBtn?{name:"append",fn:p(()=>[l(t.$slots,"append",{},void 0,!0),o.showMenuBtn?(a(),m(d,{key:0,variant:"list",icon:"mdi-dots-vertical",onClick:e[0]||(e[0]=u(s=>t.$emit("menu",s),["stop"]))})):w("",!0)]),key:"0"}:void 0]),1040)),[[f,s=>t.$emit("menu",s)]])}const b=h(y,[["render",C],["__scopeId","data-v-c69d76bf"]]);export{b as L};
