.v-item-group{flex:0 1 auto;max-width:100%;position:relative;transition:.2s cubic-bezier(.4,0,.2,1)}.v-tooltip>.v-overlay__content{background:rgb(var(--v-theme-surface-variant));color:rgb(var(--v-theme-on-surface-variant));border-radius:4px;font-size:.875rem;line-height:1.6;display:inline-block;padding:5px 16px;text-transform:initial;width:auto;opacity:1;pointer-events:none;transition-property:opacity,transform;overflow-wrap:break-word}.v-tooltip>.v-overlay__content[class*=enter-active]{transition-timing-function:cubic-bezier(0,0,.2,1);transition-duration:.15s}.v-tooltip>.v-overlay__content[class*=leave-active]{transition-timing-function:cubic-bezier(.4,0,1,1);transition-duration:75ms}.hiresicon[data-v-e9b09e11]{margin-top:5px;margin-right:15px;margin-left:15px;filter:invert(100%)}.hiresicondark[data-v-e9b09e11]{margin-top:5px;margin-right:15px;margin-left:15px}.panel-item[data-v-9508fb1a]{height:100%;padding:10px;border:none;border-style:none!important}.panel-item-checkbox[data-v-9508fb1a]{position:absolute;width:100%;height:auto;left:0;right:0}.panel-item-details[data-v-9508fb1a]{margin-top:10px;padding-left:0!important;padding-right:0!important;height:40px}.panel-item-actions[data-v-9508fb1a]{padding:0;margin:10px 0 0;height:40px;min-height:unset!important}panel-item-details[data-v-9508fb1a] .v-list-item__content{height:30px}.v-card--active[data-v-9508fb1a]{background-color:red}.hiresicon[data-v-9508fb1a]{margin-right:10px}.hiresiconinverted[data-v-9508fb1a]{margin-right:10px;filter:invert(100%)}.alert{margin-right:10px}.col-2[data-v-c8e6e4c0]{width:50%;max-width:50%;flex-basis:50%;padding:8px}.col-3[data-v-c8e6e4c0]{width:33.3%;max-width:33.3%;flex-basis:33.3%;padding:8px}.col-4[data-v-c8e6e4c0]{width:25%;max-width:25%;flex-basis:25%;padding:8px}.col-5[data-v-c8e6e4c0]{width:20%;max-width:20%;flex-basis:20%;padding:8px}.col-6[data-v-c8e6e4c0]{width:16.6%;max-width:16.6%;flex-basis:16.6%;padding:8px}.col-7[data-v-c8e6e4c0]{width:14.2%;max-width:14.2%;flex-basis:14.2%;padding:8px}.col-8[data-v-c8e6e4c0]{width:12.5%;max-width:12.5%;flex-basis:12.5%;padding:8px}.col-9[data-v-c8e6e4c0]{width:11.1%;max-width:11.1%;flex-basis:11.1%;padding:8px}
