import{m as v,c as o,b as S,e as x,B as A,w as h,K as f,d as G,a as J,f as K,Y as Q,E as U,F as W,g as Y,Z,G as $,W as q,i as X,I as ee,k as ae,u as te,l as ne,S as de,O as ie,H as le,n as se,_ as ce,A as re,U as ue,J as ve}from"./VListItem-ab7a82e2.js";import{m,C as oe,f as n,l as C,az as u,F as p,v as me,I as ye,z as P,Q as be,R as ke}from"./index-103db515.js";import{V as ge,a as fe}from"./VCardText-1a59cac1.js";const Ce=m()({name:"VCardActions",props:v(),setup(e,d){let{slots:t}=d;return oe({VBtn:{slim:!0,variant:"text"}}),o(()=>{var a;return n("div",{class:["v-card-actions",e.class],style:e.style},[(a=t.default)==null?void 0:a.call(t)])}),{}}}),Ie=C({opacity:[Number,String],...v(),...S()},"VCardSubtitle"),Ve=m()({name:"VCardSubtitle",props:Ie(),setup(e,d){let{slots:t}=d;return o(()=>n(e.tag,{class:["v-card-subtitle",e.class],style:[{"--v-card-subtitle-opacity":e.opacity},e.style]},t)),{}}}),Ae=C({appendAvatar:String,appendIcon:u,prependAvatar:String,prependIcon:u,subtitle:[String,Number],title:[String,Number],...v(),...x()},"VCardItem"),he=m()({name:"VCardItem",props:Ae(),setup(e,d){let{slots:t}=d;return o(()=>{var s;const a=!!(e.prependAvatar||e.prependIcon),y=!!(a||t.prepend),l=!!(e.appendAvatar||e.appendIcon),b=!!(l||t.append),k=!!(e.title!=null||t.title),g=!!(e.subtitle!=null||t.subtitle);return n("div",{class:["v-card-item",e.class],style:e.style},[y&&n("div",{key:"prepend",class:"v-card-item__prepend"},[t.prepend?n(f,{key:"prepend-defaults",disabled:!a,defaults:{VAvatar:{density:e.density,image:e.prependAvatar},VIcon:{density:e.density,icon:e.prependIcon}}},t.prepend):n(p,null,[e.prependAvatar&&n(A,{key:"prepend-avatar",density:e.density,image:e.prependAvatar},null),e.prependIcon&&n(h,{key:"prepend-icon",density:e.density,icon:e.prependIcon},null)])]),n("div",{class:"v-card-item__content"},[k&&n(ge,{key:"title"},{default:()=>{var i;return[((i=t.title)==null?void 0:i.call(t))??e.title]}}),g&&n(Ve,{key:"subtitle"},{default:()=>{var i;return[((i=t.subtitle)==null?void 0:i.call(t))??e.subtitle]}}),(s=t.default)==null?void 0:s.call(t)]),b&&n("div",{key:"append",class:"v-card-item__append"},[t.append?n(f,{key:"append-defaults",disabled:!l,defaults:{VAvatar:{density:e.density,image:e.appendAvatar},VIcon:{density:e.density,icon:e.appendIcon}}},t.append):n(p,null,[e.appendIcon&&n(h,{key:"append-icon",density:e.density,icon:e.appendIcon},null),e.appendAvatar&&n(A,{key:"append-avatar",density:e.density,image:e.appendAvatar},null)])])])}),{}}}),pe=C({appendAvatar:String,appendIcon:u,disabled:Boolean,flat:Boolean,hover:Boolean,image:String,link:{type:Boolean,default:void 0},prependAvatar:String,prependIcon:u,ripple:{type:[Boolean,Object],default:!0},subtitle:[String,Number],text:[String,Number],title:[String,Number],...G(),...v(),...x(),...J(),...K(),...Q(),...U(),...W(),...Y(),...Z(),...S(),...me(),...$({variant:"elevated"})},"VCard"),Be=m()({name:"VCard",directives:{Ripple:q},props:pe(),setup(e,d){let{attrs:t,slots:a}=d;const{themeClasses:y}=ye(e),{borderClasses:l}=X(e),{colorClasses:b,colorStyles:k,variantClasses:g}=ee(e),{densityClasses:s}=ae(e),{dimensionStyles:i}=te(e),{elevationClasses:B}=ne(e),{loaderClasses:T}=de(e),{locationStyles:_}=ie(e),{positionClasses:D}=le(e),{roundedClasses:L}=se(e),c=ce(e,t),N=P(()=>e.link!==!1&&c.isLink.value),r=P(()=>!e.disabled&&e.link!==!1&&(e.link||c.isClickable.value));return o(()=>{const R=N.value?"a":e.tag,F=!!(a.title||e.title!=null),E=!!(a.subtitle||e.subtitle!=null),O=F||E,w=!!(a.append||e.appendAvatar||e.appendIcon),z=!!(a.prepend||e.prependAvatar||e.prependIcon),H=!!(a.image||e.image),M=O||z||w,j=!!(a.text||e.text!=null);return be(n(R,{class:["v-card",{"v-card--disabled":e.disabled,"v-card--flat":e.flat,"v-card--hover":e.hover&&!(e.disabled||e.flat),"v-card--link":r.value},y.value,l.value,b.value,s.value,B.value,T.value,D.value,L.value,g.value,e.class],style:[k.value,i.value,_.value,e.style],href:c.href.value,onClick:r.value&&c.navigate,tabindex:e.disabled?-1:void 0},{default:()=>{var I;return[H&&n("div",{key:"image",class:"v-card__image"},[a.image?n(f,{key:"image-defaults",disabled:!e.image,defaults:{VImg:{cover:!0,src:e.image}}},a.image):n(re,{key:"image-img",cover:!0,src:e.image},null)]),n(ue,{name:"v-card",active:!!e.loading,color:typeof e.loading=="boolean"?void 0:e.loading},{default:a.loader}),M&&n(he,{key:"item",prependAvatar:e.prependAvatar,prependIcon:e.prependIcon,title:e.title,subtitle:e.subtitle,appendAvatar:e.appendAvatar,appendIcon:e.appendIcon},{default:a.item,prepend:a.prepend,title:a.title,subtitle:a.subtitle,append:a.append}),j&&n(fe,{key:"text"},{default:()=>{var V;return[((V=a.text)==null?void 0:V.call(a))??e.text]}}),(I=a.default)==null?void 0:I.call(a),a.actions&&n(Ce,null,{default:a.actions}),ve(r.value,"v-card")]}}),[[ke("ripple"),r.value&&e.ripple]])}),{}}});export{Be as V,Ve as a,Ce as b};
