.list-item{padding:0 8px!important}.list-item>div.ListItem__prepend{padding-right:10px}.mediadetails-streamdetails{width:30px;height:14px;border-radius:2px;font-size:x-small;font-weight:800;min-width:55px;padding:0;box-shadow:none}.mediadetails-content-type-btn{height:25px!important;width:50px!important;padding:5px!important;font-weight:500;font-size:10px!important;letter-spacing:.1em;border-radius:2px;flex-flow:column;margin:0}.v-avatar.v-avatar--density-default[data-v-cb7319ee]{height:100%!important;width:100%!important}.menurow[data-v-2d0d7afd] .v-list-item__prepend{width:45px;margin-left:-5px}.menurow[data-v-2d0d7afd] .v-expansion-panel-title{padding:0 10px 0 0;min-height:40px!important;height:40px!important}.menurow[data-v-2d0d7afd] .v-expansion-panel-title--active{height:40px!important}.menurow[data-v-2d0d7afd] .v-expansion-panel-text__wrapper{padding:0}.v-checkbox.v-input{flex:0 1 auto}.v-checkbox .v-selection-control{min-height:var(--v-input-control-height)}
