import{d as s,a5 as m,z as n,X as e,c as l,g as c,f as u,b as f}from"./index-103db515.js";import{I as h}from"./ItemsListing-7bf0c0b0.js";import"./VCheckbox-ddd5d7c4.js";import"./eventbus-6e1536e2.js";import"./VListItem-ab7a82e2.js";import"./VCheckboxBtn-19bafbc9.js";import"./VList-cac73f62.js";import"./VCardText-1a59cac1.js";import"./VCard-d4f085fd.js";import"./VMenu-482e7fbc.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-91f42136.js";import"./Button-412f73ce.js";import"./VSpacer-adcb10ea.js";/* empty css              */import"./PanelviewItemCompact-5ede3757.js";import"./VAlert-4165d2e6.js";import"./Container-d98651c4.js";import"./Toolbar-908bc969.js";import"./VToolbar-dcf67568.js";import"./VTextField-73438668.js";import"./VInfiniteScroll-c2610a44.js";import"./layout-e7ad5131.js";import"./VVirtualScroll-b23fb9a8.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{J as default};
