import{X as r,m as s,b as o,c}from"./VListItem-ab7a82e2.js";import{l as m,m as n,f as i}from"./index-103db515.js";const x=r("v-card-title"),l=m({opacity:[Number,String],...s(),...o()},"VCardText"),C=n()({name:"VCardText",props:l(),setup(t,a){let{slots:e}=a;return c(()=>i(t.tag,{class:["v-card-text",t.class],style:[{"--v-card-text-opacity":t.opacity},t.style]},e)),{}}});export{x as V,C as a};
