.v-layout{--v-scrollbar-offset: 0px;display:flex;flex:1 1 auto}.v-layout--full-height{--v-scrollbar-offset: inherit;height:100%}.background-image[data-v-bf62b41d]{position:absolute}.background-image .v-img__img--cover[data-v-bf62b41d]{object-position:50% 20%}.v-card--variant-elevated[data-v-bf62b41d]{box-shadow:none;border-width:1px;border-style:solid;font-size:smaller}
